================
DS2STAC-Ingester
================



.. image:: https://img.shields.io/pypi/v/ds2stac_ingester.svg
        :target: https://pypi.python.org/pypi/ds2stac_ingester


.. image:: https://img.shields.io/travis/CAT4KIT/ds2stac_ingester.svg
        :target: https://travis-ci.com/CAT4KIT/ds2stac_ingester

.. image:: https://readthedocs.org/projects/ds2stac-ingester/badge/?version=latest
        :target: https://ds2stac-ingester.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




A python-based module to ingest STAC metadata catalogs into STAC-databases like pgSTAC


* Free software: EUPL-1.2
* Documentation: https://ds2stac-ingester.readthedocs.io.


Features
--------

* TODO

Copyright
---------
Copyright © 2023 Karlsruher Institut für Technologie

Licensed under the EUPL-1.2-or-later

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the EUPL-1.2 license for more details.

You should have received a copy of the EUPL-1.2 license along with this
program. If not, see https://www.eupl.eu/.